@@ -1,18 +1,9 @@
 #
 # ovirt-engine-setup -- ovirt engine setup
-# Copyright (C) 2013-2015 Red Hat, Inc.
 #
-# Licensed under the Apache License, Version 2.0 (the "License");
-# you may not use this file except in compliance with the License.
-# You may obtain a copy of the License at
+# Copyright oVirt Authors
+# SPDX-License-Identifier: Apache-2.0
 #
-#     http://www.apache.org/licenses/LICENSE-2.0
-#
-# Unless required by applicable law or agreed to in writing, software
-# distributed under the License is distributed on an "AS IS" BASIS,
-# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
-# See the License for the specific language governing permissions and
-# limitations under the License.
 #
 
 
@@ -54,11 +45,13 @@ class Plugin(plugin.PluginBase):
             if self.environment[oenginecons.CoreEnv.ENABLE]:
                 self.dialog.note(
                     text=_(
-                        'Please note: Data Warehouse is required for the '
-                        'engine. If you choose to not configure it on this '
-                        'host, you have to configure it on a remote host, and '
-                        'then configure the engine on this host so that it '
-                        'can access the database of the remote Data '
+                        '\n* Please note * : Data Warehouse is required for '
+                        'the engine.\n'
+                        'If you choose to not configure it on this host, you '
+                        'have to configure\n'
+                        'it on a remote host, and then configure the engine '
+                        'on this host so\n'
+                        'that it can access the database of the remote Data '
                         'Warehouse host.'
                     )
                 )
